package com.esignlive.example;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.Group;
import com.silanis.esl.sdk.GroupId;
import com.silanis.esl.sdk.GroupMember;
import com.silanis.esl.sdk.GroupMemberType;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.builder.GroupBuilder;
import com.silanis.esl.sdk.builder.GroupMemberBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;

import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;

import java.util.List;
import java.util.UUID;

public class groups {

	public static void main(String[] args) {

		// replace api_key placeholder with your own value
		String API_KEY = "api_key";
		String API_URL = "https://sandbox.e-signlive.com/api";

		EslClient esl = new EslClient(API_KEY, API_URL);

		/*---------------------------------Creating Groups----------------------------------------*/
		
		Group group1 = GroupBuilder.newGroup("My Group").withId(new GroupId(UUID.randomUUID().toString()))
				.withEmail("mygroup@aol.com").withIndividualMemberEmailing()
				.withMember(GroupMemberBuilder.newGroupMember("esl.signer@example.com").as(GroupMemberType.REGULAR))
				.build();
		
		Group createdGroup1 = esl.getGroupService().createGroup(group1);

		Group emptyGroup = GroupBuilder.newGroup("Java developers").withId(new GroupId("group1"))
				.withEmail("esl.signer@example.com").withoutIndividualMemberEmailing().build();

		Group createdEmptyGroup = esl.getGroupService().createGroup(emptyGroup);

		esl.getGroupService().inviteMember(createdEmptyGroup.getId(),
				GroupMemberBuilder.newGroupMember("esl.signer@example.com").as(GroupMemberType.REGULAR).build());

		esl.getGroupService().inviteMember(createdEmptyGroup.getId(),
				GroupMemberBuilder.newGroupMember("esl.signer@example.com").as(GroupMemberType.REGULAR).build());

		/*-----------------------------------Retrieve Groups----------------------------------------------*/
		
		List<Group> allGroups = esl.getGroupService().getMyGroups();
		for (Group group : allGroups) {
			System.out.println(group.getName() + " with email " + group.getEmail() + " and id " + group.getId());
			List<GroupMember> allMembers = esl.getGroupService().getGroupMembers(group.getId());
			for (GroupMember member : allMembers) {
				System.out.println(member.getGroupMemberType().toString() + " " + member.getFirstName() + " "
						+ member.getLastName() + " with email " + member.getEmail());
			}
			System.out.print("\n");
		}

		Group myGroup = allGroups.get(1);
		
		/*---------------------------------------Add group signer to package--------------------------------------*/

		DocumentPackage myPackage = newPackageNamed("My Package with Group Signers Java Developers")
				.withSigner(SignerBuilder.newSignerFromGroup(myGroup.getId()).canChangeSigner()
						.deliverSignedDocumentsByEmail())
				.withDocument(newDocumentWithName("My Document").fromFile("DOC_FILE_PATH")
						.withSignature(signatureFor(myGroup.getId()).onPage(0).atPosition(370, 680)))
				.build();

		PackageId packageId = esl.createAndSendPackage(myPackage);
	}
}
